check_names_exist: Check if a set of column names are found in a data frame and...

View source: R/checks.R

check_names_existR Documentation

Check if a set of column names are found in a data frame and return an error if not

Description

Check if a set of column names are found in a data frame and return an error if not

Usage

check_names_exist(data, names)

Arguments

data

a data.frame to check names against

names

the inputted column names


sftrack documentation built on May 18, 2026, 9:06 a.m.