step_recalc: recalculate step geometry

View source: R/step_calculation.R

step_recalcR Documentation

recalculate step geometry

Description

Step geometeries in sftraj objects are linestrings going from t1 to t2 of a 'step'. As these are stored at the row level they are not dynamic to changes in t2. step_recalc allows you to recalculate these geometeries if your data.frame has changed because of subsetting or filtering.

Usage

step_recalc(x, return = FALSE)

Arguments

x

an sftraj object.

return

return step_geometry instead of replacing sftraj object with new step geometry. Defaults to FALSE


sftrack documentation built on May 18, 2026, 9:06 a.m.